@@ -1,14 +1,14 @@
 package Chart::GGPlot::Backend::Plotly::Geom::Blank;
 
-# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Blank
+# ABSTRACT: Chart::GGPlot's Plotly implementation for Geom::Blank
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0003'; # VERSION
+our $VERSION = '0.0005'; # VERSION
 
 with qw(Chart::GGPlot::Backend::Plotly::Geom);
 
-classmethod to_trace ($df, $params, @rest) { }
+classmethod to_traces ($df, @rest) { [] }
 
 __PACKAGE__->meta->make_immutable;
 
@@ -22,11 +22,11 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Geom::Blank - Chart::GGPlot's Plotly support for Geom::Blank
+Chart::GGPlot::Backend::Plotly::Geom::Blank - Chart::GGPlot's Plotly implementation for Geom::Blank
 
 =head1 VERSION
 
-version 0.0003
+version 0.0005
 
 =head1 SEE ALSO
 
