@@ -1,10 +1,10 @@
 package Chart::GGPlot::Backend::Plotly::Geom::Path;
 
-# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Path
+# ABSTRACT: Chart::GGPlot's Plotly implementation for Geom::Path
 
 use Chart::GGPlot::Class qw(:pdl);
 
-our $VERSION = '0.0003'; # VERSION
+our $VERSION = '0.0005'; # VERSION
 
 with qw(Chart::GGPlot::Backend::Plotly::Geom);
 
@@ -15,15 +15,44 @@ use Chart::GGPlot::Backend::Plotly::Util qw(
 );
 use Chart::GGPlot::Util qw(ifelse);
 
+classmethod split_on () { [qw(fill color size)] }
+
 sub mode {
     return 'lines';
 }
 
-classmethod marker ($df, @rest) {
+classmethod scatter_marker ($df, @rest) {
     return;
 }
 
-classmethod to_trace ($df, $params, $plot) {
+classmethod scatter_line ($df, $params, $plot) {
+    my $use_webgl = $class->use_webgl($df);
+    my $plotly_trace_class =
+      $use_webgl
+      ? 'Chart::Plotly::Trace::Scattergl'
+      : 'Chart::Plotly::Trace::Scatter';
+
+    my $line_class = "${plotly_trace_class}::Line";
+    load $line_class;
+
+    # TODO: plotly does not yet support gradient line color and width
+    #  See https://github.com/plotly/plotly.js/issues/581
+
+    my $color = to_rgb( $df->at('color'), $df->at('alpha') )->at(0);
+    my $size  = cex_to_px( $df->at('size')->slice( pdl(0) ) );
+    $size->where($size < 2) .= 2;
+
+    # plotly supports solid, dashdot, dash, dot
+    my $linetype = $df->at('linetype')->at(0);
+
+    return $line_class->new(
+        color => $color,
+        width => $size->at(0),
+        ( $linetype ne 'solid' ? ( dash => $linetype ) : () ),
+    );
+}
+
+classmethod to_traces ($df, $params, $plot) {
     $df = group_to_NA($df);
 
     my $use_webgl = $class->use_webgl($df);
@@ -39,28 +68,15 @@ classmethod to_trace ($df, $params, $plot) {
     }
 
     my ( $x, $y ) = map { $df->at($_) } qw(x y);
-    my $marker = $class->marker( $df, $params, $plot );
-
     my $mode = $class->mode;
-    my $line;
-    if ( $mode eq 'lines' ) {
-
-        # TODO: plotly does not yet support gradient line color and width
-        #  See https://github.com/plotly/plotly.js/issues/581
-
-        my $color = to_rgb( $df->at('color')->slice( pdl(0) ) );
-        my $size  = cex_to_px( $df->at('size')->slice( pdl(0) ) );
-        $size = ifelse( $size < 2, 2, $size );
-
-        # plotly supports solid, dashdot, dash, dot
-        my $linetype = $df->at('linetype')->at(0);
-
-        $line = {
-            color => $color->at(0),
-            width => $size->at(0),
-            ( $linetype ne 'solid' ? ( dash => $linetype ) : () ),
-        };
-    }
+    my $marker =
+        $mode eq 'markers'
+      ? $class->scatter_marker( $df, $params, $plot )
+      : undef;
+    my $line =
+        $mode eq 'lines'
+      ? $class->scatter_line( $df, $params, $plot )
+      : undef;
 
     my $trace = $plotly_trace_class->new(
         x    => $x,
@@ -70,19 +86,11 @@ classmethod to_trace ($df, $params, $plot) {
           line => $line,
         maybe
           marker => $marker,
-
-        # TODO: hovertext for webgl does not seem to work. Maybe it's
-        #  because of large data count. To revisit this in future.
-        (
-            $use_webgl
-            ? ()
-            : (
-                hovertext => pdl_to_plotly( $df->at('hovertext') ),
-                hoverinfo => 'text',
-            )
-        ),
+        hovertext => pdl_to_plotly( $df->at('hovertext') ),
+        hoverinfo => 'text',
+        hoveron   => $class->hover_on,
     );
-    return $class->_adjust_trace_for_flip($trace, $plot);
+    return [ $class->_adjust_trace_for_flip($trace, $plot) ];
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -97,11 +105,11 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Geom::Path - Chart::GGPlot's Plotly support for Geom::Path
+Chart::GGPlot::Backend::Plotly::Geom::Path - Chart::GGPlot's Plotly implementation for Geom::Path
 
 =head1 VERSION
 
-version 0.0003
+version 0.0005
 
 =head1 SEE ALSO
 
