@@ -1,10 +1,10 @@
 package Chart::GGPlot::Backend::Plotly::Geom::Point;
 
-# ABSTRACT: Chart::GGPlot's Plotly support for Geom::Point
+# ABSTRACT: Chart::GGPlot's Plotly implementation for Geom::Point
 
 use Chart::GGPlot::Class;
 
-our $VERSION = '0.0003'; # VERSION
+our $VERSION = '0.0005'; # VERSION
 
 extends qw(Chart::GGPlot::Backend::Plotly::Geom::Path);
 
@@ -17,14 +17,14 @@ sub mode {
     return 'markers';
 }
 
-classmethod marker ($df, $params, @rest) {
+classmethod scatter_marker ($df, $params, @rest) {
     my $color = to_rgb( $df->at('color') );
     my $fill =
       $df->exists('fill')
       ? ifelse( $df->at('fill')->isbad, $color, to_rgb( $df->at('fill') ) )
       : $color;
     my $size = cex_to_px( $df->at('size') );
-    $size = ifelse( $size > 2, $size, 2 );
+    $size->where($size < 2) .= 2;
     my $opacity = $df->at('alpha')->setbadtoval(1);
     my $stroke  = cex_to_px( $df->at('stroke') );
 
@@ -63,11 +63,11 @@ __END__
 
 =head1 NAME
 
-Chart::GGPlot::Backend::Plotly::Geom::Point - Chart::GGPlot's Plotly support for Geom::Point
+Chart::GGPlot::Backend::Plotly::Geom::Point - Chart::GGPlot's Plotly implementation for Geom::Point
 
 =head1 VERSION
 
-version 0.0003
+version 0.0005
 
 =head1 SEE ALSO
 
