@@ -5,14 +5,14 @@ package Chart::GGPlot::ScalesList;
 use Chart::GGPlot::Class qw(:pdl);
 use namespace::autoclean;
 
-our $VERSION = '0.0003'; # VERSION
+our $VERSION = '0.0005'; # VERSION
 
-use Data::Munge qw(elem);
 use List::AllUtils qw(pairmap pairkeys);
 use Types::Standard qw(Any ArrayRef Object);
 use Type::Params;
 use PDL::Primitive qw(which);
 
+use Chart::GGPlot::Aes::Functions qw(aes_to_scale);
 use Chart::GGPlot::Scale::Functions qw(find_scale);
 use Chart::GGPlot::Types qw(:all);
 use Chart::GGPlot::Util qw(:all);
@@ -45,7 +45,7 @@ method add ($scale) {
     my $prev_aes = $self->find( $scale->aesthetics );
     if ( $prev_aes->any ) {
         my $aes_name =
-          $self->scales->slice( $prev_aes->flatten )->aesthetics->[0];
+          $self->scales->slice( [ $prev_aes->at(0) ] )->aesthetics->[0];
         my $message =
           sprintf( "Scale for '%s' is already present. "
               . "Adding another scale for '%s', which will replace the existing scale.",
@@ -128,6 +128,7 @@ method transform_df ($df) {
 method add_defaults ($data, $aesthetics) {
     return if ( $aesthetics->isempty );
 
+    $aesthetics = $aesthetics->rename(\&aes_to_scale);
     my $new_aesthetics = $aesthetics->names->setdiff( $self->input );
 
     # No new aesthetics, so no new scales to add
@@ -143,7 +144,7 @@ method add_defaults ($data, $aesthetics) {
         my ( $scale_f, $func_name ) = find_scale( $aes, $datacols{$aes} );
         unless ( defined $scale_f ) {
             # some aesthetics do not have scale functions
-            if ( elem( $aes, [qw(weight)] ) ) {
+            if ( List::AllUtils::any { $aes eq $_ } (qw(weight width)) ) {
                 next;
             }
             else {
@@ -190,7 +191,7 @@ Chart::GGPlot::ScalesList - Encapsulation multiple scale objects
 
 =head1 VERSION
 
-version 0.0003
+version 0.0005
 
 =head1 ATTRIBUTES
 
